%define ver 2.01
%define patchlevel 10

Name: webalizer
Summary: A flexible Web server log file analysis program.
Group: Applications/Internet
Version: %{ver}_%{patchlevel}
Release: 25
URL: http://www.mrunix.net/webalizer/
License: GPL
Buildroot: %{_tmppath}/%{name}-root

Source0: ftp://ftp.mrunix.net/pub/webalizer/%{name}-%{ver}-%{patchlevel}-src.tar.bz2
Source1: webalizer.conf
Source2: webalizer.cron
Source3: webalizer-httpd.conf

Patch0:  webalizer-2.01-06-rh.patch
Patch1: dns-db1.patch
Patch2: webalizer-2.01_10-lfs.patch
Patch3: webalizer-2.01-10-overflow.patch
Patch4: webalizer-2.01-10-underrun.patch
Patch5: webalizer-2.01-10-ipv6.patch

BuildPrereq: gd-devel
BuildPrereq: zlib-devel
BuildPrereq: libpng-devel
BuildPrereq: db4-devel

Prereq: shadow-utils
Prereq: fileutils

Requires: webserver, crontabs

%description
The Webalizer is a Web server log analysis program. It is designed to
scan Web server log files in various formats and produce usage
statistics in HTML format for viewing through a browser. It produces
professional looking graphs which make analyzing when and where your
Web traffic is coming from easy.

%prep
%setup -q -n %{name}-%{ver}-%{patchlevel}
%patch0 -p1 -b .rh
%patch1 -p1 -b .db1
%patch2 -p1 -b .lfs
%patch3 -p1 -b .overflow
%patch4 -p1 -b .underrun
%patch5 -p1 -b .ipv6

%build
CPPFLAGS="-I%{_includedir}/db4" ; export CPPFLAGS
CFLAGS="$RPM_OPT_FLAGS $CPPFLAGS -D_LARGEFILE64_SOURCE" ; export CFLAGS
%configure --enable-dns --with-dblib=/lib

make

%install
rm -fr $RPM_BUILD_ROOT

mkdir -p $RPM_BUILD_ROOT%{_bindir} \
         $RPM_BUILD_ROOT/%{_mandir}/man1 \
         $RPM_BUILD_ROOT/var/www/usage \
         $RPM_BUILD_ROOT/etc/cron.daily

mkdir -p $RPM_BUILD_ROOT/var/lib/webalizer

%makeinstall

install -m 644 $RPM_SOURCE_DIR/webalizer.conf $RPM_BUILD_ROOT/etc
install -m 644 *.png $RPM_BUILD_ROOT/var/www/usage
install -m 755 %{SOURCE2} $RPM_BUILD_ROOT/etc/cron.daily/00webalizer
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/httpd/conf.d
install -m 644 $RPM_SOURCE_DIR/webalizer-httpd.conf \
        $RPM_BUILD_ROOT%{_sysconfdir}/httpd/conf.d/webalizer.conf

%clean
rm -rf $RPM_BUILD_ROOT

%pre
/usr/sbin/adduser -c "Webalizer" -u 67 \
	-s /sbin/nologin -r -d /var/www/usage webalizer 2>/dev/null || :

%post
# are we upgrading?
if [ $1 -gt 1 ]; then
  if [ -f /var/www/html/usage/webalizer.current ]; then
	mv /var/www/html/usage/webalizer.current /var/lib/webalizer
  fi
  if [ -f /var/www/html/usage/webalizer.hist ]; then
	mv /var/www/html/usage/webalizer.hist /var/lib/webalizer
  fi
  for i in /var/lib/webalizer/* /var/www/html/usage/*; do
   [ -f "$i" ] && /bin/chown webalizer $i
  done
fi
exit 0

%triggerpostun -- webalizer <= 2.0
# older files incompatible with 2.01 and later
# trigger will run (if necessary) after postinstall script
if [ -f /var/lib/webalizer/webalizer.current ]; then
  rm -f /var/lib/webalizer/webalizer.current
fi

%files
%defattr(-,root,root)
%doc README
%{_mandir}/man1/webalizer.1*
%{_bindir}/*
%config /etc/webalizer.conf
/etc/webalizer.conf.sample
%config(noreplace) /etc/cron.daily/00webalizer
%config(noreplace) /etc/httpd/conf.d/webalizer.conf
%attr(-, webalizer, root) %dir /var/www/usage
%attr(-, webalizer, root) %dir /var/lib/webalizer
%attr(-, webalizer, root) /var/www/usage/*.png

%changelog
* Wed Aug 18 2004 Joe Orton <jorton@redhat.com> 2.0_10-25
- rebuild

* Fri Jun 18 2004 Alan Cox <alan@redhat.com>
- Added IPv6 patch from PLD c/o Robert Scheck
- Added tests to trap bogus logfiles with negative times/dates
- Fixed leap seconds

* Tue Jun 15 2004 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Sat Mar 27 2004 Joe Orton <jorton@redhat.com> 2.0_10-22
- allow access to /usage from ::1 and 127.0.0.1 by default
- require crontabs

* Sun Mar 21 2004 Florian La Roche <Florian.LaRoche@redhat.de>
- keep apps owned by root:root

* Fri Feb 13 2004 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Mon Jan 12 2004 Florian La Roche <Florian.LaRoche@redhat.de> 2.0_10-19
- add an "exit 0" to post script

* Thu Jan  8 2004 Joe Orton <jorton@redhat.com> 2.01_10-18
- update default config

* Thu Jan  8 2004 Joe Orton <jorton@redhat.com> 2.01_10-17
- add fix for #111433

* Fri Nov 28 2003 Joe Orton <jorton@redhat.com> 2.01_10-16
- merge from Taroon

* Tue Oct 21 2003 Florian La Roche <Florian.LaRoche@redhat.de>
- add %%clean specfile target

* Fri Aug  1 2003 Joe Orton <jorton@redhat.com> 2.01_10-15.ent
- support large (>2gb) log files on 32-bit platforms
- move default output directory to /var/www/usage
- add conf.d/webalizer.conf to add alias for /usage
- only allow access to usage stats from localhost by default
- change default config: don't ignore out-of-sequence log entries,
  count .php and .shtml as "page" extensions.

* Thu Jul  3 2003 Joe Orton <jorton@redhat.com> 
- rebuilt

* Wed Jun 05 2003 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Thu Jun 05 2003 Florian La Roche <Florian.LaRoche@redhat.de>
- fix owner in /var/www/html/usage for "rpm -Va"

* Tue May 06 2003 Phil Knirsch <pknirsch@redhat.com> 2.01_10-12
- Bumped release and rebuilt due to new gd version.

* Wed Jan 22 2003 Tim Powers <timp@redhat.com> 2.01_10-11
- rebuilt

* Thu Nov  7 2002 Than Ngo <than@redhat.com> 2.01_10-10
- requires webserver (bug #74006)
- unpackaged file issue

* Tue Jul 02 2002 Than Ngo <than@redhat.com> 2.01_10-9
- fix a bug in post

* Mon Jul 01 2002 Than Ngo <than@redhat.com> 2.01_10-8
- fix a bug in pre (bug #67634)

* Wed Jun 27 2002 Than Ngo <than@redhat.com> 2.01_10-7
- add shadow-utils in prereq 

* Fri Jun 21 2002 Tim Powers <timp@redhat.com>
- automated rebuild

* Fri Jun 21 2002 Than Ngo <than@redhat.com> 2.01_10-5
- fixed bug #62062, #64392, #63685

* Thu May 30 2002 Nalin Dahyabhai <nalin@redhat.com> 2.01_10-4
- fixup some linkage problems (was getting db2, which shouldn't happen)

* Sun May 26 2002 Tim Powers <timp@redhat.com>
- automated rebuild

* Thu May 23 2002 Bernhard Rosenkraenzer <bero@redhat.com> 2.01_10-2
- Use db4

* Wed Apr 17 2002 Than Ngo <than@redhat.com> 2.01_10-1
- 2.01_10 fixes a posible buffer overflow bug in DNS resolver code

* Thu Mar 21 2002 Preston Brown <pbrown@redhat.com>
- put transient files in /var/lib/webalizer
- removed sysconfig runtime option.  Remove the package or cron script if 
  you do not want it to run (#59752)
- make default quiet operation

* Mon Feb 25 2002 Than Ngo <than@redhat.com> 2.01_09-5
- allows multiple partial log files to be used instead of one huge one.(bug #60295)

* Wed Feb 21 2002 Than Ngo <than@redhat.com> 2.01_09-4
- add function to enable/disable webalizer (bug #59752)

* Wed Jan 09 2002 Tim Powers <timp@redhat.com>
- automated rebuild

* Wed Nov 14 2001 Than Ngo <than@redhat.com> 2.01_09-2
- make cron jobs quiet (bug #56249)

* Wed Oct 24 2001 Bernhard Rosenkraenzer <bero@redhat.com> 2.01_09-1
- Update to 2.01-09, fixing security bugs

* Thu Sep 20 2001 Than Ngo <than@redhat.com> 2.01_06-13
- update config file (bug #53881)

* Sun Sep 16 2001 Than Ngo <than@redhat.com> 2.01_06-12
- add patch from author to fix Webalizer dumps core when MangleAgents is set to 1

* Mon Jul 16 2001 Trond Eivind Glomsrd <teg@redhat.com>
- Remove empty post
- Mark the crontab file as config(noreplace) 

* Fri Jul 13 2001 Than Ngo <than@redhat.com> 2.01_06-10
- fix build dependencies (bug #48939)
- Copyright->License

* Fri Jun 15 2001 Than Ngo <than@redhat.com>
- add missing icons (bug #43220)

* Mon May 21 2001 Tim Powers <timp@redhat.com>
- rebuilt for the distro

* Fri May 18 2001 Than Ngo <than@redhat.com>
- don't run webalizer when access log file is empty (Bug #41322)

* Wed Feb 14 2001 Tim Powers <timp@redhat.com>
- enable dns-lookups (patched to use correct db header) (bug #27612)

* Thu Feb  1 2001 Tim Powers <timp@redhat.com>
- make the cronjob called 00webalizer, so that it runs before everything else

* Wed Jan 31 2001 Tim Powers <timp@redhat.com>
- fixed bug 25351, where webalizer was being run after apache is
  logrotated.

* Tue Oct 17 2000 Than Ngo <than@redhat.com>
- update to 2.01-06

* Tue Oct 17 2000 Than Ngo <than@redhat.com>
- fixed wrong OutputDir (bug #19180)

* Thu Aug 3 2000 Tim Powers <timp@redhat.com>
- rebuilt against libpng-1.0.8

* Mon Jul 24 2000 Prospector <prospector@redhat.com>
- rebuilt

* Wed Jul 12 2000 Than Ngo <than@redhat.de>
- rebuilt

* Sun Jun 19 2000 Karsten Hopp <karsten@redhat.de>
- rebuild for 7.0
- changed mandir
- changed graph output to png instead of gif
- changed path to apache root (/var/www)

* Mon Nov 08 1999 Bernhard Rosenkrnzer <bero@redhat.com>
- handle RPM_OPT_FLAGS

* Tue Sep 28 1999 Preston Brown <pbrown@redhat.com>
- updated for Secure Web Server 3.1

* Mon May 03 1999 Preston Brown <pbrown@redhat.com>
- initial build for Secure Web Server 3.0
